@@ -38,14 +38,14 @@ Notification::Notification(QObject *parent) :
     QObject(parent)
 {
     // devices
-    foreach (const NetworkManager::Device::Ptr &device, NetworkManager::networkInterfaces()) {
+    Q_FOREACH(const NetworkManager::Device::Ptr &device, NetworkManager::networkInterfaces()) {
         addDevice(device);
     }
 
     connect(NetworkManager::notifier(), SIGNAL(deviceAdded(QString)), this, SLOT(deviceAdded(QString)));
 
     // connections
-    foreach (const NetworkManager::ActiveConnection::Ptr &ac, NetworkManager::activeConnections()) {
+    Q_FOREACH(const NetworkManager::ActiveConnection::Ptr &ac, NetworkManager::activeConnections()) {
         addActiveConnection(ac);
     }
 
@@ -318,7 +318,11 @@ void Notification::addActiveConnection(const NetworkManager::ActiveConnection::P
         NetworkManager::VpnConnection::Ptr vpnConnection = ac.objectCast<NetworkManager::VpnConnection>();
         connect(vpnConnection.data(), SIGNAL(stateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)),
                 this, SLOT(onVpnConnectionStateChanged(NetworkManager::VpnConnection::State,NetworkManager::VpnConnection::StateChangeReason)));
+#if NM_CHECK_VERSION(0, 9, 10)
+    } else if (ac->type() >= NetworkManager::ConnectionSettings::Adsl && ac->type() <= NetworkManager::ConnectionSettings::Team) {
+#else
     } else {
+#endif
         connect(ac.data(), SIGNAL(stateChanged(NetworkManager::ActiveConnection::State)),
                 this, SLOT(onActiveConnectionStateChanged(NetworkManager::ActiveConnection::State)));
     }
