@@ -21,7 +21,7 @@
 #ifndef PLASMA_NM_IPV4_WIDGET_H
 #define PLASMA_NM_IPV4_WIDGET_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 #include <NetworkManagerQt/Ipv4Setting>
 
 #include "settingwidget.h"
@@ -41,11 +41,11 @@ public:
     explicit IPv4Widget(const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(), QWidget* parent = 0, Qt::WindowFlags f = 0);
     virtual ~IPv4Widget();
 
-    void loadConfig(const NetworkManager::Setting::Ptr &setting);
+    void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
 
-    QVariantMap setting(bool agentOwned = false) const;
+    QVariantMap setting(bool agentOwned = false) const Q_DECL_OVERRIDE;
 
-    virtual bool isValid() const;
+    virtual bool isValid() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void slotModeComboChanged(int index);
@@ -65,7 +65,7 @@ private:
     NetworkManager::Ipv4Setting m_tmpIpv4Setting;
 
     class Private;
-    Private *d;
+    Private * const d;
 };
 
 #endif // PLASMA_NM_IPV4_WIDGET_H
